@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.2.0 $
+### $Release: 0.2.1 $
 ### $Copyright: copyright(c) 2010 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -19,7 +19,7 @@ import os, re
 from glob import glob
 from kook.utils import read_file, write_file
 
-release = prop('release', '0.2.0')
+release = prop('release', '0.2.1')
 package = prop('package', 'Oktest')
 copyright = prop('copyright', "copyright(c) 2010 kuwata-lab.com all rights reserved")
 
@@ -49,7 +49,7 @@ def task_package(c):
     ## edit files
     repl = (
         (r'\$Release\$', release),
-        (r'\$Release: 0.2.0 $', '$Release: 0.2.0 $' % release),
+        (r'\$Release: 0.2.1 $', '$Release: 0.2.1 $' % release),
         (r'\$Copyright\$', copyright),
         (r'\$Package\$', package),
         (r'\$License\$', license),
@@ -107,3 +107,33 @@ def task_uninstall(c):
 def task_clean(c):
     pass
     from glob import glob
+
+@recipe
+@product('website/index.html')
+@ingreds('README.txt')
+def file_website_index_html(c):
+    #opts = '--stylesheet-path=website/style.css --link-stylesheet'
+    #with chdir('website'):
+    #    system(c%'rst2html.py $(opts) ../README.txt > index.html')
+    opts = '--stylesheet-path=style.css --link-stylesheet --strip-class=field --strip-class=field-name --strip-class=field-body'
+    system(c%'rst2html.py $(opts) $(ingred) > $(product)')
+    def f(s):
+        s = s.replace('$Release: 0.2.1 $', '$Release: 0.2.1 $' % release)
+        s = s.replace('0.2.1', release)
+        s = s.replace('README', 'Oktest - a new style testing library -')
+        #s = re.sub(r'^<h(\d)>(.*?)</h\d>', r, s)
+        pat = re.compile(r'^<h(\d)>(.*?)</h\d>', re.M)
+        def r(m):
+            n = int(m.group(1)) + 1
+            s = m.group(2)
+            return '\n<h%s>%s</h%s>' % (n, s, n)
+        s = re.sub(pat, r, s)
+        return s
+    edit(c.product, by=f)
+    with chdir("website"):
+        system("zip -r ../Oktest.zip index.html style.css")
+
+@recipe
+@ingreds('website/index.html')
+def task_website(c):
+    pass
